==> WhakerPy-0.2-py3-none-any.whl: whakerpy/httpd/__init__.py <==
# -*- coding: UTF-8 -*-
"""
:filename: sppas.ui.whakerpy.httpd.__init__.py
:author:   Brigitte Bigi
:contact:  develop@sppas.org
:summary:  Manage an HTTPD server and an handler for any web-based app.

.. _This file is part of SPPAS: https://sppas.org/
..
    -------------------------------------------------------------------------

     ___   __    __    __    ___
    /     |  \  |  \  |  \  /              the automatic
    \__   |__/  |__/  |___| \__             annotation and
       \  |     |     |   |    \             analysis
    ___/  |     |     |   | ___/              of speech

    Copyright (C) 2011-2023  Brigitte Bigi
    Laboratoire Parole et Langage, Aix-en-Provence, France

    Use of this software is governed by the GNU Public License, version 3.

    SPPAS is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    SPPAS is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with SPPAS. If not, see <http://www.gnu.org/licenses/>.

    This banner notice must not be removed.

    -------------------------------------------------------------------------

"""

from .hstatus import sppasHTTPDValueError
from .hstatus import sppasHTTPDStatus
from .handler import sppasHTTPDHandler
from .hserver import sppasBaseHTTPDServer
from .hresponse import BaseResponseRecipe

__all__ = (
    "BaseResponseRecipe",
    "sppasHTTPDStatus",
    "sppasHTTPDValueError",
    "sppasHTTPDHandler",
    "sppasBaseHTTPDServer")

==> WhakerPy-0.3.1-py3-none-any.whl: whakerpy/httpd/__init__.py <==
# -*- coding: UTF-8 -*-
"""
:filename: sppas.ui.whakerpy.httpd.__init__.py
:author:   Brigitte Bigi
:contact:  contact@sppas.org
:summary:  Manage an HTTPD server and an handler for any web-based app.

.. _This file is part of SPPAS: https://sppas.org/
..
    -------------------------------------------------------------------------

     ___   __    __    __    ___
    /     |  \  |  \  |  \  /              the automatic
    \__   |__/  |__/  |___| \__             annotation and
       \  |     |     |   |    \             analysis
    ___/  |     |     |   | ___/              of speech

    Copyright (C) 2011-2023  Brigitte Bigi
    Laboratoire Parole et Langage, Aix-en-Provence, France

    Use of this software is governed by the GNU Public License, version 3.

    SPPAS is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    SPPAS is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with SPPAS. If not, see <https://www.gnu.org/licenses/>.

    This banner notice must not be removed.

    -------------------------------------------------------------------------

"""

from .hstatus import HTTPDValueError
from .hstatus import HTTPDStatus
from .handler import HTTPDHandler
from .hserver import BaseHTTPDServer
from .hresponse import BaseResponseRecipe

__all__ = (
    "BaseResponseRecipe",
    "HTTPDStatus",
    "HTTPDValueError",
    "HTTPDHandler",
    "BaseHTTPDServer")
